# eric7.HelpViewer.HelpBookmarkPropertiesDialog

Module implementing a dialog to edit the bookmark properties.

### Global Attributes

None

### Classes

HelpBookmarkPropertiesDialog | Class implementing a dialog to edit the bookmark properties.

### Functions

None

## HelpBookmarkPropertiesDialog

Class implementing a dialog to edit the bookmark properties.

### Derived from

QDialog, Ui_HelpBookmarkPropertiesDialog

### Class Attributes

None

### Class Methods

None

### Methods

HelpBookmarkPropertiesDialog | Constructor
__updateOkButton | Private method to set the enabled state of the OK button.
getData | Public method to retrieve the entered data.

### Static Methods

None

#### HelpBookmarkPropertiesDialog (Constructor)

HelpBookmarkPropertiesDialog(title="", url="", parent=None)

Constructor

title (str (optional))
  title for the bookmark (defaults to "")
url (str (optional))
  URL for the bookmark (defaults to "")
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

#### HelpBookmarkPropertiesDialog.__updateOkButton

__updateOkButton()

Private method to set the enabled state of the OK button.

#### HelpBookmarkPropertiesDialog.getData

getData()

Public method to retrieve the entered data.

Return:
  tuple containing the title and URL for the bookmark

Return Type:
  tuple of (str, str)

Up